.. reducer documentation master file, created by
   sphinx-quickstart on Fri Jul 25 11:25:06 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. highlight:: python
   :linenothreshold: 5

reducer: Friendly astronomical image reduction
=============================================

Want to use reducer in a class?
-------------------------------

Want to use reducer in a class and need some help getting started/advice on
use? There is a *very* brief summary of how I've used with undergraduates at
:ref:`use_with_students`.

**Please contact me** at `mattwcraig@gmail.com
<mailto:mattwcraig@gmail.com?subject=Reducer>`_ or open an issue on the
`GitHub site for reducer`_ if you have questions, run into problems, or want
to let me know how you are using it!


Short walkthrough video
-----------------------

The YouTube video below has a walkthrough of the reducer notebook. No
explanatory audio or text, check out the :ref:`quickstart` for that.

.. raw:: html

    <iframe width="640" height="480" src="https://www.youtube-nocookie.com/embed/fhyursvZPU0?rel=0&amp;showinfo=0" frameborder="0" allowfullscreen></iframe>




Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   use-with-students
   gui
   image_browser
   astro_gui

.. toctree::
   :maxdepth: 1

   authors_for_sphinx
   changelog

.. _GitHub site for reducer: https://github.com/mwcraig/reducer
